@@ -47,8 +47,8 @@
 #include "../libmuonapt/QAptActions.h"
 
 // Libmuon includes
+#include <Transaction/TransactionModel.h>
 #include <resources/ResourcesModel.h>
-#include <MuonBackendsFactory.h>
 
 // Own includes
 #include "ApplicationLauncher.h"
@@ -63,9 +63,9 @@ enum ViewModelRole {
     /// A role for storing ViewType
     ViewTypeRole = Qt::UserRole + 1,
     /// A role for storing origin filter data
-    OriginFilterRole = Qt::UserRole + 2,
+    OriginFilterRole,
     /// A role for storing state filter data
-    StateFilterRole = Qt::UserRole + 3
+    StateFilterRole
 };
 
 enum ViewType {
@@ -90,10 +90,17 @@ MainWindow::MainWindow()
     , m_launcherMessage(nullptr)
     , m_appLauncher(nullptr)
     , m_progressItem(nullptr)
-    , m_transactionCount(0)
 {
     initGUI();
-    QTimer::singleShot(10, this, SLOT(initObject()));
+
+    TransactionModel *transModel = TransactionModel::global();
+    connect(transModel, SIGNAL(startingFirstTransaction()), SLOT(addProgressItem()));
+    connect(transModel, SIGNAL(lastTransactionFinished()), SLOT(removeProgressItem()));
+    m_launches = new LaunchListModel(this);
+
+    ResourcesModel* resourcesModel = ResourcesModel::global();
+    resourcesModel->integrateMainWindow(this);
+    connect(resourcesModel, SIGNAL(backendsChanged()), SLOT(initObject()));
 }
 
 MainWindow::~MainWindow()
@@ -148,37 +155,18 @@ void MainWindow::initGUI()
 
 void MainWindow::initObject()
 {
-    // Initialize singleton ResourcesModel instance. It will live in the main thread
-    // and all future calls to ResourcesModel::global() will refer to it.
-    Q_ASSERT(ResourcesModel::global() == nullptr);
-    ResourcesModel *resourcesModel = new ResourcesModel(this);
-    connect(resourcesModel, SIGNAL(transactionAdded(Transaction*)),
-            this, SLOT(transactionAdded()));
-    connect(resourcesModel, SIGNAL(transactionRemoved(Transaction*)),
-            this, SLOT(transactionRemoved()));
+    ResourcesModel *resourcesModel = ResourcesModel::global();
 
-    m_launches = new LaunchListModel(this);
-
-    MuonBackendsFactory f;
-    QList<AbstractResourcesBackend*> backends = f.allBackends();
-
-    //TODO: should add the appBackend here too
+    QVector<AbstractResourcesBackend*> backends = resourcesModel->backends();
     for (AbstractResourcesBackend *backend : backends) {
-        resourcesModel->addResourcesBackend(backend);
-        backend->integrateMainWindow(this);
-        
-        if(backend->metaObject()->className()==QLatin1String("ApplicationBackend")) {
+        if(!m_appBackend &&
+            backend->metaObject()->className()==QLatin1String("ApplicationBackend"))
+        {
             m_appBackend = backend;
-            connect(m_appBackend, SIGNAL(backendReady()),
-                    this, SLOT(populateViews()));
-            connect(m_appBackend, SIGNAL(reloadStarted()), //TODO: use ResourcesModel signals
-                    this, SLOT(removeProgressItem()));
-            connect(m_appBackend, SIGNAL(reloadFinished()),
-                    this, SLOT(showLauncherMessage()));
-            connect(m_appBackend, SIGNAL(startingFirstTransaction()),
-                    this, SLOT(addProgressItem()));
-            connect(m_appBackend, SIGNAL(sourcesEditorFinished()),
-                    this, SLOT(sourcesEditorFinished()));
+            connect(m_appBackend, SIGNAL(backendReady()), SLOT(populateViews()));
+            connect(m_appBackend, SIGNAL(reloadFinished()), SLOT(showLauncherMessage()));
+            connect(m_appBackend, SIGNAL(sourcesEditorFinished()), SLOT(sourcesEditorFinished()));
+            populateViews();
         }
     }
 }
@@ -284,6 +272,7 @@ QPair<QStringList, QStringList> fetchOrigins()
 
 void MainWindow::populateViews()
 {
+    m_viewModel->clear();
     QStandardItem *availableItem = new QStandardItem;
     availableItem->setEditable(false);
     availableItem->setIcon(KIcon("applications-other").pixmap(32,32));
@@ -444,20 +433,6 @@ void MainWindow::clearMessageActions()
     }
 }
 
-void MainWindow::transactionAdded()
-{
-    m_transactionCount++;
-}
-
-void MainWindow::transactionRemoved()
-{
-    if (m_transactionCount)
-        m_transactionCount--;
-
-    if (!m_transactionCount)
-        removeProgressItem();
-}
-
 void MainWindow::addProgressItem()
 {
     QStandardItem *parentItem = m_viewModel->invisibleRootItem();
