@@ -58,12 +58,11 @@
 
 // Libmuon includes
 #include <resources/AbstractResource.h>
+#include <resources/AbstractResourcesBackend.h>
 #include <MuonStrings.h>
 #include <ReviewsBackend/Rating.h>
 #include <ReviewsBackend/Review.h>
 #include <ReviewsBackend/AbstractReviewsBackend.h>
-#include <Transaction/TransactionListener.h>
-#include <resources/AbstractResource.h>
 
 // std includes
 #include <math.h>
@@ -74,6 +73,7 @@
 #include "qml/src/mousecursor.h"
 #include "ReviewsWidget/ReviewsWidget.h"
 #include "ScreenShotOverlay.h"
+#include "Transaction/TransactionListener.h"
 
 #define BLUR_RADIUS 15
 
@@ -291,13 +291,13 @@ ResourceDetailsWidget::ResourceDetailsWidget(QWidget *parent)
     layout->addWidget(detailsWidget);
     layout->addWidget(m_reviewsWidget);
     layout->addWidget(verticalSpacer);
-    
-    m_listener = new TransactionListener(this);
 
-    connect(m_listener, SIGNAL(progressChanged()), SLOT(progressChanged()));
-    connect(m_listener, SIGNAL(commentChanged()), SLOT(progressCommentChanged()));
-    connect(m_listener, SIGNAL(running(bool)), SLOT(applicationRunningChanged(bool)));
-    connect(m_listener, SIGNAL(downloading(bool)), SLOT(applicationDownloadingChanged(bool)));
+    m_listener = new TransactionListener(this);
+    // FIXME
+//    connect(m_listener, SIGNAL(progressChanged()), SLOT(progressChanged()));
+    connect(m_listener, SIGNAL(statusTextChanged()), SLOT(progressCommentChanged()));
+    connect(m_listener, SIGNAL(runningChanged()), SLOT(applicationRunningChanged()));
+    connect(m_listener, SIGNAL(cancellableChanged()), SLOT(cancellableChanged()));
 
     setWidget(widget);
 }
@@ -311,7 +311,6 @@ void ResourceDetailsWidget::setResource(AbstractResource *resource)
 {
     m_resource = resource;
     m_listener->setResource(m_resource);
-    m_listener->setBackend(m_resource->backend());
 
     AbstractResource *app = qobject_cast<AbstractResource*>(resource);
 
@@ -485,19 +484,16 @@ void ResourceDetailsWidget::cancelButtonClicked()
 
 void ResourceDetailsWidget::fetchReviews(int page)
 {
-    if (!m_resource) {
-	return;
-    }
+    if (!m_resource)
+        return;
 
     m_resource->backend()->reviewsBackend()->fetchReviews(m_resource, page);
-
 }
 
 void ResourceDetailsWidget::populateReviews(AbstractResource *app, const QList<Review *> &reviews)
 {
-    if (app != m_resource) {
+    if (app != m_resource)
         return;
-    }
 
     m_reviewsWidget->addReviews(reviews);
 }
@@ -510,25 +506,27 @@ void ResourceDetailsWidget::addonsApplyButtonClicked()
     m_progressBar->setFormat(i18nc("@info:status Progress text when waiting", "Waiting"));
 }
 
-void ResourceDetailsWidget::applicationRunningChanged(bool running)
+void ResourceDetailsWidget::applicationRunningChanged()
 {
+    bool running = m_listener->isActive();
     m_actionButton->setVisible(!running);
     m_progressBar->setVisible(running);
 }
 
-void ResourceDetailsWidget::applicationDownloadingChanged(bool downloading)
+void ResourceDetailsWidget::cancellableChanged()
 {
-    m_cancelButton->setVisible(downloading);
+    m_cancelButton->setVisible(m_listener->isCancellable());
 }
 
 void ResourceDetailsWidget::progressChanged()
 {
-    m_progressBar->setValue(m_listener->progress());
+    // FIXME
+    //m_progressBar->setValue(m_listener->progress());
 }
 
 void ResourceDetailsWidget::progressCommentChanged()
 {
-    m_progressBar->setFormat(m_listener->comment());
+    m_progressBar->setFormat(m_listener->statusText());
 }
 
 void ResourceDetailsWidget::updateActionButton()
