@@ -62,11 +62,12 @@ QVariant ApplicationAddonsModel::data(const QModelIndex& index, int role) const
         case Qt::ToolTipRole:
             return m_initial[index.row()].description();
         case Qt::CheckStateRole: {
-            QHash<QString, bool>::const_iterator it = m_state.constFind(m_initial[index.row()].name());
-            if(it==m_state.constEnd()) {
-                return m_initial[index.row()].isInstalled();
+            PackageState init = m_initial[index.row()];
+            AddonList::State state = m_state.addonState(init.name());
+            if(state == AddonList::None) {
+                return init.isInstalled();
             } else {
-                return it.value();
+                return state == AddonList::ToInstall ? Qt::Checked : Qt::Unchecked;
             }
         }
     }
@@ -90,17 +91,19 @@ void ApplicationAddonsModel::applyChanges()
 
 void ApplicationAddonsModel::changeState(const QString& packageName, bool installed)
 {
-    QList<PackageState>::const_iterator it=m_initial.constBegin(), itEnd=m_initial.constEnd();
-    for(; it!=itEnd; ++it) {
+    auto it = m_initial.constBegin();
+    for(; it != m_initial.constEnd(); ++it) {
         if(it->name()==packageName)
             break;
     }
     
     bool restored = it->isInstalled()==installed;
+
     if(restored)
-        m_state.remove(packageName);
+        m_state.resetAddon(packageName);
     else
-        m_state.insert(packageName, installed);
+        m_state.addAddon(packageName, installed);
+
     emit stateChanged();
 }
 
