@@ -23,6 +23,7 @@
 
 // Qt includes
 #include <QtCore/QObject>
+#include <QPointer>
 
 // LibQApt includes
 #include <LibQApt/Globals>
@@ -48,24 +49,48 @@ public:
     void start();
     void setBackend(QApt::Backend* b);
     long unsigned int remainingTime() const;
+    virtual void addResources(const QList<AbstractResource*>& apps);
+    virtual void removeResources(const QList<AbstractResource*>& apps);
+    virtual QList<AbstractResource*> toUpdate() const;
+    virtual bool isAllMarked() const;
+    virtual QDateTime lastUpdate() const;
+    virtual bool isCancelable() const;
+    virtual bool isProgressing() const;
+    virtual QString statusDetail() const;
+    virtual QString statusMessage() const;
+    virtual void cancel();
+    virtual quint64 downloadSpeed() const;
+    void prepare();
+    virtual QList<QAction*> messageActions() const;
+    void setupTransaction(QApt::Transaction *trans);
 
 private:
+    void setProgressing(bool progressing);
+    
+    QPointer<QApt::Transaction> m_trans;
     QApt::Backend* m_aptBackend;
-    QApt::Transaction *m_trans;
     ApplicationBackend* m_appBackend;
     int m_lastRealProgress;
     long unsigned int m_eta;
+    QApt::CacheState m_updatesCache;
+    bool m_progressing;
+    QString m_statusMessage;
+    QString m_statusDetail;
+    QList<AbstractResource*> m_toUpdate;
 
 private slots:
-    void transactionStatusChanged(QApt::TransactionStatus status);
     void errorOccurred(QApt::ErrorCode error);
-    void progressChanged(int progress);
+    void setProgress(int progress);
     void etaChanged(quint64 eta);
     void installMessage(const QString& message);
-    void setupTransaction(QApt::Transaction *trans);
-
-signals:
-    void errorSignal(QApt::ErrorCode error, QString details);
+    void provideMedium(const QString &label, const QString &medium);
+    void untrustedPrompt(const QStringList &untrustedPackages);
+    void configFileConflict(const QString &currentPath, const QString &newPath);
+    void statusChanged(QApt::TransactionStatus status);
+    void setStatusMessage(const QString& msg);
+    void setStatusDetail(const QString& msg);
+    void reloadFinished();
+    void calculateUpdates();
 };
 
 #endif // APPLICATIONUPDATES_H
