@@ -34,18 +34,16 @@ public:
 
     virtual QList<AbstractResource*> upgradeablePackages() const;
     virtual AbstractResource* resourceByPackageName(const QString& name) const;
-    virtual QList<Transaction*> transactions() const;
-    virtual QPair< TransactionStateTransition, Transaction* > currentTransactionState() const;
     virtual int updatesCount() const;
     virtual AbstractBackendUpdater* backendUpdater() const;
     virtual AbstractReviewsBackend* reviewsBackend() const;
-    virtual QStringList searchPackageName(const QString& searchText);
+    virtual QList<AbstractResource*> searchPackageName(const QString& searchText);
     virtual QVector<AbstractResource*> allResources() const;
     virtual bool isValid() const { return true; } // No external file dependencies that could cause runtime errors
 
     virtual void cancelTransaction(AbstractResource* app);
     virtual void installApplication(AbstractResource* app);
-    virtual void installApplication(AbstractResource* app, const QHash< QString, bool >& addons);
+    virtual void installApplication(AbstractResource* app, AddonList addons);
     virtual void removeApplication(AbstractResource* app);
 
 private:
