@@ -27,11 +27,7 @@
 DummyReviewsBackend::DummyReviewsBackend(DummyBackend* parent)
     : AbstractReviewsBackend(parent)
 {
-    foreach(AbstractResource* app, parent->allResources()) {
-        Rating* rating = new Rating(app->packageName(), app->name(), 3, 4, "1,2,3,4,5");
-        m_ratings.insert(app, rating);
-    }
-    emit ratingsReady();
+    connect(parent, SIGNAL(backendReady()), SLOT(initialize()));
 }
 
 void DummyReviewsBackend::fetchReviews(AbstractResource* app, int page)
@@ -48,3 +44,17 @@ Rating* DummyReviewsBackend::ratingForApplication(AbstractResource* app) const
 {
     return m_ratings[app];
 }
+
+void DummyReviewsBackend::initialize()
+{
+    DummyBackend* b = qobject_cast<DummyBackend*>(parent());
+    foreach(AbstractResource* app, b->allResources()) {
+        Rating* rating = new Rating(app->packageName(), app->name(), 3, 4, "1,2,3,4,5");
+        m_ratings.insert(app, rating);
+    }
+    emit ratingsReady();
+}
+
+void DummyReviewsBackend::submitUsefulness(Review* r, bool useful)
+{
+}
