@@ -20,10 +20,12 @@
 
 #include "QAptActions.h"
 #include "MuonStrings.h"
+#include "HistoryView/HistoryView.h"
 
 // Qt includes
 #include <QtCore/QDir>
 #include <QtCore/QStringBuilder>
+#include <QDebug>
 
 // KDE includes
 #include <KAction>
@@ -46,11 +48,12 @@
 #include "MuonMainWindow.h"
 
 QAptActions::QAptActions()
-    : QObject(0)
-    , m_backend(0)
+    : QObject(nullptr)
+    , m_backend(nullptr)
     , m_actionsDisabled(false)
-    , m_mainWindow(0)
+    , m_mainWindow(nullptr)
     , m_reloadWhenEditorFinished(false)
+    , m_historyDialog(nullptr)
 {
     connect(Solid::Networking::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),
             this, SLOT(networkChanged()));
@@ -65,13 +68,19 @@ QAptActions* QAptActions::self()
     return self.data();
 }
 
-void QAptActions::setMainWindow(KXmlGuiWindow* w)
+void QAptActions::setMainWindow(MuonMainWindow* w)
 {
     setParent(w);
     m_mainWindow = w;
+    connect(m_mainWindow, SIGNAL(actionsEnabledChanged(bool)), SLOT(setActionsEnabledInternal(bool)));
     setupActions();
 }
 
+MuonMainWindow* QAptActions::mainWindow() const
+{
+    return m_mainWindow;
+}
+
 void QAptActions::setBackend(QApt::Backend* backend)
 {
     m_backend = backend;
@@ -81,6 +90,7 @@ void QAptActions::setBackend(QApt::Backend* backend)
     connect(m_backend, SIGNAL(packageChanged()), this, SLOT(setActionsEnabled()));
 
     setOriginalState(m_backend->currentCacheState());
+
     setReloadWhenEditorFinished(true);
     // Some actions need an initialized backend to be able to set their enabled state
     setActionsEnabled(true);
@@ -88,18 +98,6 @@ void QAptActions::setBackend(QApt::Backend* backend)
 
 void QAptActions::setupActions()
 {
-    KAction* updateAction = m_mainWindow->actionCollection()->addAction("update");
-    updateAction->setIcon(KIcon("system-software-update"));
-    updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
-    updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
-    connect(updateAction, SIGNAL(triggered()), SIGNAL(checkForUpdates()));
-    if (!isConnected()) {
-        updateAction->setDisabled(true);
-    }
-    connect(this, SIGNAL(shouldConnect(bool)), updateAction, SLOT(setEnabled(bool)));
-    m_actions.append(updateAction);
-
-
     KAction* undoAction = KStandardAction::undo(this, SLOT(undo()), actionCollection());
     actionCollection()->addAction("undo", undoAction);
     m_actions.append(undoAction);
@@ -115,6 +113,7 @@ void QAptActions::setupActions()
     m_actions.append(revertAction);
 
     KAction* softwarePropertiesAction = actionCollection()->addAction("software_properties");
+    softwarePropertiesAction->setPriority(QAction::LowPriority);
     softwarePropertiesAction->setIcon(KIcon("configure"));
     softwarePropertiesAction->setText(i18nc("@action Opens the software sources configuration dialog", "Configure Software Sources"));
     connect(softwarePropertiesAction, SIGNAL(triggered()), this, SLOT(runSourcesEditor()));
@@ -133,12 +132,14 @@ void QAptActions::setupActions()
     m_actions.append(saveSelectionsAction);
 
     KAction* createDownloadListAction = actionCollection()->addAction("save_download_list");
+    createDownloadListAction->setPriority(QAction::LowPriority);
     createDownloadListAction->setIcon(KIcon("document-save-as"));
     createDownloadListAction->setText(i18nc("@action", "Save Package Download List..."));
     connect(createDownloadListAction, SIGNAL(triggered()), this, SLOT(createDownloadList()));
     m_actions.append(createDownloadListAction);
 
     KAction* downloadListAction = actionCollection()->addAction("download_from_list");
+    downloadListAction->setPriority(QAction::LowPriority);
     downloadListAction->setIcon(KIcon("download"));
     downloadListAction->setText(i18nc("@action", "Download Packages From List..."));
     connect(downloadListAction, SIGNAL(triggered()), this, SLOT(downloadPackagesFromList()));
@@ -149,19 +150,39 @@ void QAptActions::setupActions()
     m_actions.append(downloadListAction);
 
     KAction* loadArchivesAction = actionCollection()->addAction("load_archives");
+    loadArchivesAction->setPriority(QAction::LowPriority);
     loadArchivesAction->setIcon(KIcon("document-open"));
     loadArchivesAction->setText(i18nc("@action", "Add Downloaded Packages"));
     connect(loadArchivesAction, SIGNAL(triggered()), this, SLOT(loadArchives()));
     m_actions.append(loadArchivesAction);
     
     KAction* saveInstalledAction = actionCollection()->addAction("save_package_list");
+    saveInstalledAction->setPriority(QAction::LowPriority);
     saveInstalledAction->setIcon(KIcon("document-save-as"));
     saveInstalledAction->setText(i18nc("@action", "Save Installed Packages List..."));
     connect(saveInstalledAction, SIGNAL(triggered()), this, SLOT(saveInstalledPackagesList()));
+    
+    KAction* historyAction = actionCollection()->addAction("history");
+    historyAction->setPriority(QAction::LowPriority);
+    historyAction->setIcon(KIcon("view-history"));
+    historyAction->setText(i18nc("@action::inmenu", "History..."));
+    historyAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_H));
+    connect(historyAction, SIGNAL(triggered()), this, SLOT(showHistoryDialog()));
+
+    KAction *distUpgradeAction = actionCollection()->addAction("dist-upgrade");
+    distUpgradeAction->setIcon(KIcon("system-software-update"));
+    distUpgradeAction->setText(i18nc("@action", "Upgrade"));
+    distUpgradeAction->setPriority(QAction::HighPriority);
+    distUpgradeAction->setWhatsThis(i18nc("Notification when a new version of Kubuntu is available",
+                                        "A new version of Kubuntu is available."));
+    distUpgradeAction->setEnabled(false);
+    connect(distUpgradeAction, SIGNAL(triggered(bool)), SLOT(launchDistUpgrade()));
+    checkDistUpgrade();
+
     m_actions.append(saveInstalledAction);
 }
 
-void QAptActions::setActionsEnabled(bool enabled)
+void QAptActions::setActionsEnabledInternal(bool enabled)
 {
     m_actionsDisabled = !enabled;
 
@@ -174,17 +195,17 @@ void QAptActions::setActionsEnabled(bool enabled)
 
     actionCollection()->action("update")->setEnabled(isConnected() && enabled);
 
-    actionCollection()->action("undo")->setEnabled(!m_backend->isUndoStackEmpty());
-    actionCollection()->action("redo")->setEnabled(!m_backend->isRedoStackEmpty());
-    actionCollection()->action("revert")->setEnabled(!m_backend->isUndoStackEmpty());
+    actionCollection()->action("undo")->setEnabled(m_backend && !m_backend->isUndoStackEmpty());
+    actionCollection()->action("redo")->setEnabled(m_backend && !m_backend->isRedoStackEmpty());
+    actionCollection()->action("revert")->setEnabled(m_backend && !m_backend->isUndoStackEmpty());
     
     actionCollection()->action("save_download_list")->setEnabled(isConnected());
 
-    bool changesPending = m_backend->areChangesMarked();
-    actionCollection()->action("open_markings")->setEnabled(true);
+    bool changesPending = m_backend && m_backend->areChangesMarked();
     actionCollection()->action("save_markings")->setEnabled(changesPending);
     actionCollection()->action("save_download_list")->setEnabled(changesPending);
-    actionCollection()->action("save_package_list")->setEnabled(true);
+    actionCollection()->action("dist-upgrade")->setEnabled(false);
+    checkDistUpgrade();
 }
 
 bool QAptActions::reloadWhenSourcesEditorFinished() const
@@ -199,7 +220,6 @@ bool QAptActions::isConnected() const {
     return connected;
 }
 
-
 void QAptActions::networkChanged()
 {
     if (m_actionsDisabled)
@@ -407,7 +427,7 @@ void QAptActions::sourcesEditorFinished(int exitStatus)
     bool reload = (exitStatus != 0);
     m_mainWindow->find(m_mainWindow->effectiveWinId())->setEnabled(true);
     if (m_reloadWhenEditorFinished && reload) {
-        emit checkForUpdates();
+        actionCollection()->action("update")->trigger();
     }
 
     emit sourcesEditorClosed(reload);
@@ -440,3 +460,98 @@ void QAptActions::initError()
     KMessageBox::detailedError(m_mainWindow, text, details, title);
     exit(-1);
 }
+
+void QAptActions::displayTransactionError(QApt::ErrorCode error, QApt::Transaction* trans)
+{
+    if (error == QApt::Success)
+        return;
+
+    MuonStrings *muonStrings = MuonStrings::global();
+
+    QString title = muonStrings->errorTitle(error);
+    QString text = muonStrings->errorText(error, trans);
+
+    switch (error) {
+        case QApt::InitError:
+        case QApt::FetchError:
+        case QApt::CommitError:
+            KMessageBox::detailedError(QAptActions::self()->mainWindow(), text, trans->errorDetails(), title);
+            break;
+        default:
+            KMessageBox::error(QAptActions::self()->mainWindow(), text, title);
+            break;
+    }
+}
+
+void QAptActions::showHistoryDialog()
+{
+    if (!m_historyDialog) {
+        m_historyDialog = new KDialog(mainWindow());
+
+        KConfigGroup dialogConfig(KSharedConfig::openConfig("muonrc"),
+                                  "HistoryDialog");
+        m_historyDialog->restoreDialogSize(dialogConfig);
+
+        connect(m_historyDialog, SIGNAL(finished()), SLOT(closeHistoryDialog()));
+        HistoryView *historyView = new HistoryView(m_historyDialog);
+        m_historyDialog->setMainWidget(historyView);
+        m_historyDialog->setWindowTitle(i18nc("@title:window", "Package History"));
+        m_historyDialog->setWindowIcon(KIcon("view-history"));
+        m_historyDialog->setButtons(KDialog::Close);
+        m_historyDialog->show();
+    } else {
+        m_historyDialog->raise();
+    }
+}
+
+void QAptActions::closeHistoryDialog()
+{
+    KConfigGroup dialogConfig(KSharedConfig::openConfig("muonrc"), "HistoryDialog");
+    m_historyDialog->saveDialogSize(dialogConfig, KConfigBase::Persistent);
+    m_historyDialog->deleteLater();
+    m_historyDialog = nullptr;
+}
+
+void QAptActions::setActionsEnabled(bool enabled)
+{
+    if(m_mainWindow)
+        m_mainWindow->setActionsEnabled(enabled);
+    else
+        setActionsEnabledInternal(enabled);
+}
+
+void QAptActions::launchDistUpgrade()
+{
+    KProcess *proc = new KProcess(this);
+    QStringList arguments;
+    QString kdesudo = KStandardDirs::findExe("kdesudo");
+    QString upgrader = QString("do-release-upgrade -m desktop -f DistUpgradeViewKDE");
+
+    arguments << kdesudo << upgrader;
+    proc->setProgram(arguments);
+    proc->start();
+
+    connect(proc, SIGNAL(finished(int)), proc, SLOT(deleteLater()));
+}
+
+void QAptActions::checkDistUpgrade()
+{
+    if(!QFile::exists("/usr/lib/python3/dist-packages/DistUpgrade/DistUpgradeFetcherKDE.py")) {
+        qWarning() << "Couldn't find the /usr/lib/python3/dist-packages/DistUpgrade/DistUpgradeFetcherKDE.py file";
+    }
+    QString checkerFile = KStandardDirs::locate("data", "muon-notifier/releasechecker");
+    if(checkerFile.isEmpty()) {
+        qWarning() << "Couldn't find the releasechecker script";
+    }
+
+    KProcess* checkerProcess = new KProcess(this);
+    checkerProcess->setProgram(QStringList() << "/usr/bin/python3" << checkerFile);
+    connect(checkerProcess, SIGNAL(finished(int)), this, SLOT(checkerFinished(int)));
+    connect(checkerProcess, SIGNAL(finished(int)), checkerProcess, SLOT(deleteLater()));
+    checkerProcess->start();
+}
+
+void QAptActions::checkerFinished(int res)
+{
+    QAptActions::self()->actionCollection()->action("dist-upgrade")->setEnabled(res == 0);
+}
