@@ -21,23 +21,14 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-// LibQApt includes
-#include <LibQApt/Globals>
-
 // Own includes
 #include "../libmuon/MuonMainWindow.h"
 
-class AbstractResourcesBackend;
+class ResourcesUpdatesModel;
 class KAction;
 class KDialog;
 class KMessageWidget;
 class KProcess;
-
-namespace QApt {
-    class Backend;
-    class Transaction;
-}
-
 class ChangelogWidget;
 class ProgressWidget;
 class UpdaterSettingsDialog;
@@ -50,47 +41,28 @@ public:
     MainWindow();
 
 private:
-    QApt::Backend* backend() const;
-    QApt::Transaction *m_trans;
-    QString m_pipe;
+    ResourcesUpdatesModel* m_updater;
 
     ProgressWidget *m_progressWidget;
     UpdaterWidget *m_updaterWidget;
-    ChangelogWidget *m_changelogWidget;
     UpdaterSettingsDialog *m_settingsDialog;
-    KDialog *m_historyDialog;
     KMessageWidget *m_powerMessage;
-    KMessageWidget *m_distUpgradeMessage;
-
     KAction *m_applyAction;
-    KAction *m_historyAction;
+    QMenu* m_moreMenu;
+    QMenu* m_advancedMenu;
 
-    KProcess *m_checkerProcess;
-    AbstractResourcesBackend* m_apps;
+    virtual void setActionsEnabled(bool enabled = true);
 
 private Q_SLOTS:
     void initGUI();
     void initBackend();
     void setupActions();
-    void transactionStatusChanged(QApt::TransactionStatus status);
-    void errorOccurred(QApt::ErrorCode error);
-    void reload();
-    void setActionsEnabled(bool enabled = true);
-    void checkForUpdates();
-    void startCommit();
-    void setupTransaction(QApt::Transaction *trans);
+    void setupBackendsActions();
     void editSettings();
     void closeSettingsDialog();
-    void showHistoryDialog();
-    void closeHistoryDialog();
     void checkPlugState();
     void updatePlugState(bool plugged);
-    void checkDistUpgrade();
-    void checkerFinished(int res);
-    void launchDistUpgrade();
-
-Q_SIGNALS:
-    void backendReady(QApt::Backend *backend);
+    void progressingChanged();
 };
 
 #endif // MAINWINDOW_H
