@@ -23,10 +23,7 @@
 
 #include <QtGui/QStackedWidget>
 
-// LibQApt includes
-#include <LibQApt/Globals>
-#include <LibQApt/Package>
-
+class ResourcesUpdatesModel;
 class KMessageWidget;
 class AbstractResource;
 class AbstractResourcesBackend;
@@ -34,52 +31,47 @@ class QItemSelection;
 class QLabel;
 class QStandardItemModel;
 class QTreeView;
+class ChangelogWidget;
 
 class KPixmapSequenceOverlayPainter;
-
-namespace QApt {
-    class Backend;
-}
-
 class UpdateModel;
 
+namespace Ui {
+    class UpdaterWidgetNoUpdates;
+}
+
 class UpdaterWidget : public QStackedWidget
 {
     Q_OBJECT
 public:
     explicit UpdaterWidget(QWidget *parent = 0);
+    virtual ~UpdaterWidget();
 
 private:
-    QApt::Package* retrievePackage(AbstractResource* res);
-
-    QApt::Backend *m_backend;
-    QApt::CacheState m_oldCacheState;
     UpdateModel *m_updateModel;
 
     QTreeView *m_updateView;
+    ChangelogWidget *m_changelogWidget;
     KPixmapSequenceOverlayPainter *m_busyWidget;
-    QLabel *m_updateStatusIcon;
-    QLabel *m_notifyTitle;
-    QLabel *m_notifyDesc;
-    AbstractResourcesBackend* m_appsBackend;
-    KMessageWidget* m_upgradesWidget;
+    ResourcesUpdatesModel* m_updatesBackends;
+    KMessageWidget* m_markallWidget;
+    Ui::UpdaterWidgetNoUpdates* m_ui;
 
 public Q_SLOTS:
-    void setBackend(AbstractResourcesBackend* backend);
-    void reload();
+    void setBackend(ResourcesUpdatesModel* backend);
 
 private Q_SLOTS:
     void populateUpdateModel();
-    void checkApps(QList<AbstractResource*> apps, bool checked);
-    void checkChanges(const QHash<QApt::Package::State, QApt::PackageList> &removals);
     void selectionChanged(const QItemSelection &selected,
                           const QItemSelection &deselected);
     void checkAllMarked();
     void checkUpToDate();
     void markAllPackagesForUpgrade();
 
+    void activityChanged();
+
 signals:
-    void selectedPackageChanged(QApt::Package *Package);
+    void selectedResourceChanged(AbstractResource* res);
     void modelPopulated();
 };
 
